/* tslint:disable */
/* eslint-disable */
/**
* Initialize the library
*/
export function init_x12_translate_wasm(): void;
/**
* Formats the given `edi` string into lines, separated by the segment delimiter.
*
* # Exceptions
*
* A call will throw a JS Error IFF it panicked.
* @param {string} x12
* @returns {string}
*/
export function format(x12: string): string;
/**
* Extracts metadata from the given edi file.
*
* # Exceptions
*
* A call will throw a JS Error IFF it panicked.
* @param {string} x12
* @returns {X12Metadata}
*/
export function metadata(x12: string): X12Metadata;
/**
* Generate a 997 acknowledgment for the given edi file.
*
* # Exceptions
*
* A call will throw a JS Error IFF it panicked.
* @param {string} x12
* @param {string} isa_control_number
* @param {string} gs_control_number
* @returns {string | undefined}
*/
export function ack(x12: string, isa_control_number: string, gs_control_number: string): string | undefined;
/**
* Generate a 997 acknowledgment guide json for the given edi file.
*
* # Exceptions
*
* A call will throw a JS Error IFF it panicked.
* @param {string} x12
* @returns {Ack997 | undefined}
*/
export function ackAsJson(x12: string): Ack997 | undefined;
/**
* Generate a 997 acknowledgment edi for the given 997 guide JSON.
*
* # Exceptions
*
* A call will throw a JS Error IFF it panicked.
* @param {Ack997} input
* @param {Envelope} envelope
* @returns {string}
*/
export function generate997(input: Ack997, envelope: Envelope): string;
/**
*/
export enum Standard {
  X12 = 0,
}
export interface AckFunctionalGroupTrailer {
    functional_group_acknowledge_code_01: string;
    number_of_transaction_sets_included_02: number;
    number_of_received_transaction_sets_03: number;
    number_of_accepted_transaction_sets_04: number;
}

export interface AckFunctionalGroupHeader {
    functional_identifier_code_01: string;
    group_control_number_02: number;
}

export interface AckTransactionSetHeader {
    transaction_set_identifier_code_01: string;
    transaction_set_control_number_02: number;
}

export interface AckHeading {
    transaction_set_header_ST: AckTransactionSetHeader;
    functional_group_response_header_AK1: AckFunctionalGroupHeader;
    functional_group_response_trailer_AK9: AckFunctionalGroupTrailer;
}

export interface Ack997 {
    heading: AckHeading;
}

export interface GroupHeader {
    functionalIdentifierCode: string;
    applicationSenderCode: string;
    applicationReceiverCode: string;
    date: string;
    time: string;
    controlNumber: string;
    release: string;
}

export interface InterchangeHeader {
    senderQualifier: string;
    senderId: string;
    receiverQualifier: string;
    receiverId: string;
    date: string;
    time: string;
    controlNumber: string;
    usageIndicatorCode: string;
    controlVersionNumber: string;
}

export interface Envelope {
    interchangeHeader: InterchangeHeader;
    groupHeader: GroupHeader;
}

export interface FunctionalGroupSegments {
    gs: string;
    ge?: string;
}

export interface FunctionalGroupEnvelope {
    functionalIdentifierCode?: string;
    applicationSenderCode?: string;
    applicationReceiverCode?: string;
    date?: string;
    time?: string;
    controlNumber?: number;
    responsibleAgencyCode?: string;
    release?: string;
    segments: FunctionalGroupSegments;
}

export interface FunctionalGroup {
    envelope: FunctionalGroupEnvelope | null;
    span: Span;
    transactionSets: TransactionSet[];
}

export interface TransactionSet {
    id?: string;
    controlNumber?: number;
    span: Span;
}

export interface InterchangeSegments {
    isa: string;
    iea?: string;
}

export interface InterchangeEnvelope {
    senderQualifier?: string;
    senderId?: string;
    receiverQualifier?: string;
    receiverId?: string;
    date?: string;
    time?: string;
    versionNumberCode?: string;
    controlNumber?: number;
    acknowledgmentRequestedCode?: string;
    usageIndicatorCode?: string;
    segments: InterchangeSegments;
}

export interface Interchange {
    envelope?: InterchangeEnvelope;
    standard: Standard;
    span: Span;
    delimiters: Delimiters | null;
    functionalGroups: FunctionalGroup[];
}

export interface Span {
    start: number;
    end: number;
}

export interface Delimiters {
    segment: string;
    element: string;
    composite: string;
    repetition: string;
}

export interface X12Metadata {
    interchanges: Interchange[];
}

